Documentation
¶
Index ¶
- type Environment
- func (e *Environment) Define(name string, value object.Object)
- func (e *Environment) Exists(name string) bool
- func (e *Environment) Get(name string) object.Object
- func (e *Environment) Set(name string, value object.Object)
- func (e *Environment) SetIndex(name string, index object.Object, value object.Object)
- func (e *Environment) SetStruct(name string, attribute string, value object.Object)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Environment ¶
type Environment struct {
Values map[string]object.Object
Parent *Environment
}
func New ¶
func New() *Environment
func NewChildEnvironment ¶
func NewChildEnvironment(parent *Environment) *Environment
func (*Environment) Exists ¶
func (e *Environment) Exists(name string) bool
Check if a name exists within the environment.
func (*Environment) Set ¶
func (e *Environment) Set(name string, value object.Object)
This method can potentially take in other context parameters So that there can be a check for something like -Wshadow
Click to show internal directories.
Click to hide internal directories.